using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.Globalization;
using System.Web;
using System.IO;
using System.Configuration;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace AspNetGallery.Extensions.Handlers
{
    // NOthing works here -- don't use. To test add, PresentationCore, WindowsBase, System.Xaml
    public class WpfDynImageHandler : IHttpHandler
    {
        public void ProcessRequest(HttpContext context)
        {
            // Process the URL param
            var o1 = context.Request["url"];
            if (o1 == null)
            {
                context.Response.Write("No image found.");
                context.Response.End();
                return;
            }
            var file = context.Server.MapPath(o1);

            // Process the thumbnail param
            var useThumbnail = false;
            var o2 = context.Request["small"];
            if (o2 != null)
            {
                Boolean.TryParse(o2, out useThumbnail);
            }

            // Read copyright string from AppSettings
            var msg = ConfigurationManager.AppSettings["CopyrightNoteForImages"];
            if (File.Exists(file))
            {
                BitmapFrame bmp;
                if (useThumbnail)
                    bmp = GetThumbnail(file);
                else
                {
                    bmp = GetThumbnail(file);
                }
                //else
                //    bmp = AddCopyright(file, msg);

                context.Response.ContentType = "image/jpeg";

                //bmp.Save(context.Response.OutputStream, ImageFormat.Jpeg);
                //bmp.Dispose();
                var targetEncoder = new JpegBitmapEncoder();
                targetEncoder.Frames.Add(bmp);
                targetEncoder.Save(context.Response.OutputStream);
            }
            else
            {
                context.Response.Write("No image found.");
                context.Response.End();
            }
        }

        public bool IsReusable
        {
            get
            {
                return true;
            }
        }

        #region Helpers
        private static BitmapFrame GetThumbnail(string file)
        {
            var bi = new BitmapImage();
            bi.BeginInit();
            bi.UriSource = new Uri(file);
            var width = bi.PixelWidth/2;
            var height = bi.PixelHeight/2;
            bi.DecodePixelWidth = width;
            bi.DecodePixelHeight = height;
            bi.EndInit();
            return BitmapFrame.Create(bi); 

            //var bmp = BitmapFrame.Create(new Uri(file),
            //    BitmapCreateOptions.DelayCreation,
            //    BitmapCacheOption.None);
            //return bmp.Thumbnail;

            //var bmp = new Bitmap(file);
            //var newImg = (Bitmap) bmp.GetThumbnailImage(
            //    bmp.Width / 2, bmp.Height / 2, null, IntPtr.Zero);
            //return newImg;

        }

        private static BitmapFrame AddCopyright(string file, string msg)
        {
            var bi = new BitmapImage();
            bi.BeginInit();
            bi.UriSource = new Uri(file);
            
            bi.EndInit();

            // Load the file and create the graphics
            var bmp = BitmapFrame.Create(new Uri(file),
                BitmapCreateOptions.DelayCreation, 
                BitmapCacheOption.None);
            var width = bmp.PixelWidth;
            var height = bmp.PixelHeight;

            // To calculate writing coordinates, obtain the size of the text
            // given font typeface and size
            var formattedText = new FormattedText(msg,
                                             CultureInfo.CurrentCulture,
                                             FlowDirection.LeftToRight,
                                             new Typeface(new System.Windows.Media.FontFamily("verdana"), 
                                                 FontStyles.Normal, 
                                                 FontWeights.Normal, 
                                                 new FontStretch()),
                                             7,
                                             System.Windows.Media.Brushes.PaleGreen);
            var textSize = new System.Windows.Size(formattedText.Width, formattedText.Height);
            

            // Calculate the output rectangle and fill
            var x = (bmp.Width - textSize.Width - 3);
            var y = (bmp.Height - textSize.Height - 3);
            var w = (x + textSize.Width);
            var h = (y + textSize.Height);
            var rect = new Rect(x, y, w, h);

            var drawing = new DrawingVisual();
            var context = drawing.RenderOpen();
            context.DrawRectangle(System.Windows.Media.Brushes.Black, 
                null, 
                rect);
            context.DrawText(formattedText, new System.Windows.Point(2, 2));
            context.Close();

            var renderBitmap = new RenderTargetBitmap(0, 0, w, h, PixelFormats.Pbgra32);
            renderBitmap.Render(drawing);
            

     
            return null;
        }
        #endregion
    }
}