using System;
using System.Collections;
using System.Web;

namespace AspNetGallery.Extensions.Modules.QueryString
{
    public class QueryStringModule : IHttpModule
    {
        private Hashtable _queryStringData;		


        #region IHttpModule
        public void Init(HttpApplication app)
        {
            // Load and cache the XML querystring file
            var fileName = HttpContext.Current.Server.MapPath("/web.querystring");
            _queryStringData = QueryStringHelper.LoadFromFile(fileName);

            app.BeginRequest += OnEnter;
        }

        public void Dispose()
        {
            // Nothing to do here
        }
        #endregion


        #region Helpers
        public void OnEnter(Object sender, EventArgs e)
        {
            var app = (HttpApplication) sender;

            // Retrieve the query string data structure for the current page
            var currentPage = HttpContext.Current.Request.Path.ToLower();
            var qsDesc = (QueryStringDescriptor) _queryStringData[currentPage];
            if (qsDesc == null)
                return;

            // Validate the query string
            var isValid = QueryStringHelper.Validate(HttpContext.Current.Request.QueryString, qsDesc);

            // Abort the request if validation fails
            if (!isValid)
            {
                if (qsDesc.AbortOnError)
                {
                    HttpContext.Current.Response.StatusCode = 500;
                    HttpContext.Current.Response.StatusDescription = "Invalid query string";
                    HttpContext.Current.Response.End();
                }
                else
                {
                    // Add information for the page to the Context.Items collection
                    HttpContext.Current.Items[QueryStringHelper.QueryStringValidationStatus] = QueryStringHelper.GetErrorCode();
                }
            }
            else
            {
                // Add information for the page to the Context.Items collection
                HttpContext.Current.Items[QueryStringHelper.QueryStringValidationStatus] = QueryStringHelper.GetErrorCode();

                // Add typed values  
                HttpContext.Current.Items[QueryStringHelper.QueryStringValues] = QueryStringHelper.GetTypedValues(HttpContext.Current.Request.QueryString, qsDesc);
            }

        }

        #endregion
    }
}
