﻿using System;
using System.Text;
using System.Text.RegularExpressions;

namespace AspNetGallery.Extensions.Utilities
{
    /// <summary>
    /// This helper method transforms a plain text string into a HTML list  
    /// either ordered or unordered. 
    /// </summary>
    public static class StringExtensions
    {
        public static String ToHtmlOrderedList(this String helper)
        {
            return ToHtmlOrderedList(helper, false);
        }

        public static String ToHtmlOrderedList(this String helper, bool orderedList)
        {
            var tagInitial = (orderedList ? "<ol>" : "<ul>");
            var tagFinal = (orderedList ? "</ol>" : "</ul>");
            var builder = new StringBuilder(tagInitial);

            var lines = Regex.Split(helper, "\r\n");
            if (lines.Length == 1)
                return helper;

            foreach(var line in lines)
            {
                if (line.StartsWith("*"))
                    continue;

                if (String.IsNullOrEmpty(line))
                {
                    builder.Append(tagFinal);
                    builder.Append(tagInitial);
                    continue;
                }
                builder.AppendFormat("<li>{0}</li>", line);
            }

            builder.Append(tagFinal);
            return builder.ToString();
        }

        public static Int32 ToInt32(this String helper, Int32 defaultValue = Int32.MinValue)
        {
            Int32 number;
            var result = Int32.TryParse(helper, out number);
            return result ? number : defaultValue;
        }
    }
}