﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using System.Web.UI.WebControls;


namespace ScriptFun
{
    public partial class _Default : Page
    {
        protected void Page_PreRender(Object sender, EventArgs e)
        {
            // Define the name and type of the client scripts on the page
            var blocks = BuildScriptBlocks();

            // Get a ClientScriptManager reference from the Page class
            var clientScriptManager = Page.ClientScript;

            // Check to see if the startup script is already registered
            if (!clientScriptManager.IsStartupScriptRegistered(blocks[0].Type, blocks[0].Name))
                clientScriptManager.RegisterStartupScript(blocks[0].Type, blocks[0].Name, blocks[0].Code, blocks[0].RequiresScriptTag);

            // Check to see if jQuery "as a script block" is already registered
            if (!clientScriptManager.IsClientScriptIncludeRegistered(blocks[1].Type, blocks[1].Name))
                clientScriptManager.RegisterClientScriptInclude(blocks[1].Type, blocks[1].Name, blocks[1].Code);

            // Check to see if the client script is already registered
            if (!clientScriptManager.IsClientScriptBlockRegistered(blocks[2].Type, blocks[2].Name))
                clientScriptManager.RegisterClientScriptBlock(blocks[2].Type, blocks[2].Name, blocks[2].Code, blocks[2].RequiresScriptTag);
        }

        private IList<ScriptBlock> BuildScriptBlocks()
        {
            var blocks = new List<ScriptBlock>();

            // Block #1 -- popup script
            var block1 = new ScriptBlock {Name = "PopupScript", Type = typeof(TextBox), Code = "alert('Hello World');", RequiresScriptTag = true};
            blocks.Add(block1);

            // Block #2 -- link jQuery
            var block2 = new ScriptBlock { Name = "jQueryScript", Type = GetType(), Code = "/Scripts/jquery-1.4.1.min.js", RequiresScriptTag = true };
            blocks.Add(block2);

            // Block #3 -- button click
            var block3 = new ScriptBlock {Name="ButtonClickScript", Type = GetType(), RequiresScriptTag = false};
            var builder = new StringBuilder();
            builder.Append("<script type=\"text/javascript\"> function DoClick() {");
            builder.Append("$('#Message').val('Text from client script.');} </");
            builder.Append("script>");
            block3.Code = builder.ToString();
            blocks.Add(block3);

            return blocks;
        }
    }
}
