﻿using System;
using System.Data;
using System.Data.SqlClient;
using System.Drawing;
using System.Text;
using System.Web.UI.WebControls;

namespace Wizards
{
    public partial class Query : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (IsPostBack)
            {
                ColumnList.Enabled = SpecifyFields.Checked;
            }
        }

        protected void OnFinish(object sender, WizardNavigationEventArgs e)
        {
            // This is also a good place to perform server-side validation.
            // This event fires just before the wizard completes.
            // TODO:: Add validation code here if no validation code exists
            //        along the way
            Trace.Warn("FinishButtonClick fired");
            var finalMsg = "The operation completed successfully.";

            // Complete the wizard (run the composed query and show results)
            try
            {
                var cmdText = DetermineCommandText();
                var adapter = new SqlDataAdapter(cmdText, ConnString.Text);
                var table = new DataTable();
                adapter.Fill(table);
                grid.DataSource = table;
                grid.DataBind();

                // OK color
                FinalMsg.ForeColor = Color.Blue;
            }
            catch (Exception ex)
            {
                FinalMsg.ForeColor = Color.Red;
                finalMsg = String.Format("The operation cannot be completed due to:<br>{0}",
                    ex.Message);
            }
            finally
            {
                // Show a final message
                FinalMsg.Text = finalMsg;
            }
        }

        protected void OnNext(object sender, WizardNavigationEventArgs e)
        {
            // This event fires when the user moves to the next step through the Next button.
            // It doesn't fire if you reach a page through the sidebar.
            // TODO:: Add validation code here if you need to move to a step only under
            //        certain conditions
            Trace.Warn("NextButtonClick fired");
            CancelMsg.Text = "";
            if (e.NextStepIndex == 1)
            {
                if (ConnString.Text.IndexOf("UID=...") > -1)
                {
                    CancelMsg.Text = "<hr>UID=... is not valid. Please fix it.";
                    e.Cancel = true;
                    return;
                }
            }

            // Collect the input data if going to the last page
            if (e.NextStepIndex == QueryWizard.WizardSteps.Count - 2)   // -1 because it's 0-based; -1 because it's last but one
            {
                PrepareFinalStep();
            }
        }

        private DataTable ExecuteCommand(string connString, string cmdText)
        {
            var adapter = new SqlDataAdapter(connString, cmdText);
            var table = new DataTable();
            adapter.Fill(table);
            return table;
        }

        private string DetermineCommandText()
        {
            // Collect data
            var fields = "*";
            if (!String.IsNullOrEmpty(ColumnList.Text))
                fields = ColumnList.Text;
            var where = "1=1";
            if (!String.IsNullOrEmpty(WhereClause.Text))
                where = WhereClause.Text;
            var top = "";
            if (!String.IsNullOrEmpty(TopX.Text))
            {
                var n = Int32.Parse(TopX.Text);
                top = String.Format("TOP {0}", n);
            }


            return String.Format("SELECT {0} {1} FROM {2} WHERE {3}", top, fields, TableList.SelectedItem.Text, where);
        }

        protected void OnViewChanged(object sender, EventArgs e)
        {
            // This event fires whenever the user changes the view--no matter the action taken.
            // This is good to use if you have Next-based validation to perform AND the sidebar. 
            // You can't cancel the event though. If Next and ViewChanged are active, Next fires first.
            Trace.Warn("ActiveViewChanged fired");
            if (QueryWizard.ActiveStepIndex == QueryWizard.WizardSteps.Count - 2)
            {
                PrepareFinalStep();
            }
        }

        private void PrepareFinalStep()
        {
            var cmdText = DetermineCommandText();

            // Show a Ready-to-go message
            var sb = new StringBuilder("");
            sb.AppendFormat("You're about to run: <br><br>{0}<hr>", cmdText);
            sb.Append("<b><br>Ready to go?</b>");
            ReadyMsg.Text = sb.ToString();
        }
    }
}